// Some useful functions for HTML code generation

#include "html.h"
extern "C" {
#include <stdlib.h>
#include <iostream.h>
#include <stdio.h>
}

HTML::HTML(string title, bool bodywhite, string description,
		string keywords, string address, string encoding,
		string generator, string extrahdr, bool hasend,
		bool hashead)
{
	head.empty();
	header.empty();
	stylesheet.empty();
	body.empty();

	if(hashead) {
		head.insert(head.end(), "<?xml version=\"1.0\" encoding=\""+encoding+"\"?>");
		head.insert(head.end(), "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">");
		head.insert(head.end(), "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\" lang=\"en\">");

		header.insert(header.end(), "<meta http-equiv=\"Content-Type\" content=\"text/html;charset="+encoding+"\" />");
		header.insert(header.end(), "<title>" + title + "</title>");
		if(!description.empty())
			header.insert(header.end(), "<meta name=\"description\" content=\"" + description + "\" />");
		if(!keywords.empty())
			header.insert(header.end(), "<meta name=\"keywords\" content=\"" + keywords + "\" />");
		if(!generator.empty())
			header.insert(header.end(), "<meta name=\"generator\" content=\"" + generator + "\" />");
		if(!address.empty())
			header.insert(header.end(), "<link rev=\"made\" href=\"mailto:" + address + "\" />");
	
		if(bodywhite)
			stylesheet.insert(stylesheet.end(), "body { background-color: white }");
	}
	if(hasend)
		end.insert(end.end(), "</body></html>");
}

HTML::~HTML()
{
}

void HTML::addText(string txt)
{
	body.insert(body.end(), txt);
}

void HTML::addForm(form &f)
{
	body.insert(body.end(), f);
}

void HTML::addSSI(string name)
{
	body.insert(body.end(), "<!--#include virtual=\""+name+"\" -->");
}

void HTML::newLine()
{
	body.insert(body.end(), "<br />");
}

void HTML::addLine()
{
	body.insert(body.end(), "<hr />");
}

void HTML::addImage(string filename, string alt, int width, int height)
{
	string s="<img src=\"" + filename + "\"";
	if(alt.empty()) alt=filename;
	s+=" alt=\"" + alt + "\"";
	if(width>=0) {
		char buf[128];
		snprintf(buf, 128, "%u", width);
		s+=" width=\"" + (string)buf + "\"";
	}
	if(height>=0) {
		char buf[128];
		snprintf(buf, 128, "%u", height);
		s+=" height=\"" + (string)buf + "\"";
	}
	s+=" />";
	body.insert(body.end(), s);
}

ostream &operator << (ostream &os, HTML &h)
{
	if(!h.head.empty())
		os << h.head;
	if(!h.header.empty()) {
		os << "<head>" << endl
		   << h.header
		   << "</head>" << endl;
		if(!h.stylesheet.empty()) {
			os << "<style type=\"text/css\">" << endl
			   << h.stylesheet
			   << "</style>" << endl;
		}
		os << "<body>" << endl;
	}
	os << h.body << endl;
	if(!h.end.empty())
		os << h.end << endl;
}

ostream &operator << (ostream &os, stringlist &s)
{
	for(stringlist::iterator i=s.begin(); i!=s.end(); i++)
		os << *i << endl;
	return os;
}
